"""Constants for repository types and configuration values."""

REPO_TYPE_SINGLE = "single-language"
REPO_TYPE_MULTI_MONOREPO = "multi-language-monorepo"
REPO_TYPE_MIXED = "mixed"

REPO_TYPES = [REPO_TYPE_SINGLE, REPO_TYPE_MULTI_MONOREPO, REPO_TYPE_MIXED]
